@@ -1,6 +1,6 @@
 package Map::Tube::Plugin::Graph;
 
-$Map::Tube::Plugin::Graph::VERSION = '0.08';
+$Map::Tube::Plugin::Graph::VERSION = '0.09';
 
 =head1 NAME
 
@@ -8,7 +8,7 @@ Map::Tube::Plugin::Graph - Graph plugin for Map::Tube.
 
 =head1 VERSION
 
-Version 0.08
+Version 0.09
 
 =cut
 
@@ -141,7 +141,7 @@ sub as_image {
                       ||
                       exists $skip->{$line}->{$to->name}->{$from}));
 
-            if (grep /$line/, (split /\,/, $to->line)) {
+            if (grep /$line/, (map { $_->name } @{$to->line})) {
                 $graph->add_edge(from => $from, to => $to->name, arrowsize => $arrowsize);
             }
             else {
